package com.edgec.browserbackend.browser.service.Impl;

import com.edgec.browserbackend.account.domain.Account;
import com.edgec.browserbackend.account.repository.AccountRepository;
import com.edgec.browserbackend.browser.ErrorCode.BrowserErrorCode;
import com.edgec.browserbackend.browser.domain.IpResource;
import com.edgec.browserbackend.browser.dto.FilterDto;
import com.edgec.browserbackend.browser.dto.IpBuyResultDto;
import com.edgec.browserbackend.browser.dto.IpResourceDto;
import com.edgec.browserbackend.browser.dto.IpResourceRequestDto;
import com.edgec.browserbackend.browser.repository.IpResourceRepository;
import com.edgec.browserbackend.browser.service.IpResourceService;
import com.edgec.browserbackend.common.commons.error.ClientRequestException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import java.util.HashMap;
import java.util.List;

@Service
public class IpResourceServiceImpl implements IpResourceService {

    private final Logger logger = LoggerFactory.getLogger(IpResourceServiceImpl.class);

    private static String CLOUDAMURL = "https://www.cloudam.cn";
    private static String TESTURL = "https://112.74.13.2";

    @Autowired
    private AccountRepository accountRepository;

    @Autowired
    private IpResourceRepository ipResourceRepository;

    public HttpHeaders buildHeader() {
        HttpHeaders header = new HttpHeaders();
        header.setContentType(MediaType.APPLICATION_JSON);
        header.setBearerAuth("5aFM6ntBcLDD8e8PGMXBybx1UsWYYWvQ0jKOal28XoMhaz7gJyxX5GtayPcY6vec");
        return header;
    }

    @Override
    public IpResource getIpResourceByIpAddr(String ipAddr) {
        IpResource ipResource = ipResourceRepository.findByAddrAndIsDeleted(ipAddr, false);
        if (ipResource == null)
            throw new ClientRequestException(BrowserErrorCode.IPNOTEXIST);
        return ipResource;
    }

    @Override
    public IpBuyResultDto buyIp(String username, IpResourceRequestDto ipResourceRequestDto) {
        RestTemplate restTemplate = new RestTemplate();
        HttpHeaders header = buildHeader();
        MultiValueMap<String, String> map = new LinkedMultiValueMap<>();
        map.add("username", username);
        map.add("name", ipResourceRequestDto.getName());
        map.add("region", ipResourceRequestDto.getRegion());
        map.add("vendor", ipResourceRequestDto.getVendor());
        map.add("unit", ipResourceRequestDto.getUnit());
        map.add("amount", String.valueOf(ipResourceRequestDto.getAmount()));
        HttpEntity<MultiValueMap<String, String>> httpEntity = new HttpEntity<>(map, header);
        IpBuyResultDto ipBuyResultDto = restTemplate.postForObject(TESTURL + "/intelligroup/ipresources?accountId={username}", httpEntity, IpBuyResultDto.class);
        return ipBuyResultDto;
    }

    @Override
    public void renewIp(String username, IpResourceRequestDto ipResourceRequestDto) {

    }

    @Override
    public void deleteIp(String username, String ipAddr) {

    }

    @Override
    public List<IpResourceDto> getIpList(String username, int type, int page, int amount, FilterDto filterDto) {
        return null;
    }


}
